@@ -12,10 +12,7 @@ class addone(object):
     def addtest(self):
         print(self.number + 1)
         print('Random numpy integer: ' + str(np.random.randint(4)))
-        for root, dirs, files in os.walk("."):
-            for filename in files:
-                print(filename)
-        sample_df = pd.DataFrame(pd.read_csv('src/examplepackagenishka/data/sample_data.csv'))
+        sample_df = pd.DataFrame(pd.read_csv('sample_data.csv'))
         print(sample_df.to_markdown())
 
 def main():
